%define	major		3
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define lib_ver		%(echo %{version}|sed -e 's/\\.//g')
%define zart_version	34ebf6cce0bafb98abe57cec83c4a02cd1abeca0

%define gimpplugin	1
%define abi_version	2.0

Name:		gmic
Version:	3.2.0
Release:	%mkrel 1
Group:		Graphics/Utilities
# CeCILL version 2.0
License:	CeCILL
Summary:	A script language (G'MIC) dedicated to image processing
Url:		https://gmic.eu/
Source0:	https://gmic.eu/files/source/%{name}_%{version}.tar.gz
Source1:	https://github.com/GreycLab/gmic-community/archive/gmic-%{version}/%{name}-community-%{version}.tar.gz
Source2:	zart.desktop
Source3: 	https://github.com/c-koi/zart/archive/%{zart_version}.tar.gz
Patch0:		gmic-3.2.0-mga-optflags.patch
Patch2:		gmic-3.1.6-qmake-flags.patch
Patch3:		gmic-3.2.0-ldflags.patch
Patch4:		gmic-dont-add-rpaths.patch
BuildRequires:	dos2unix
BuildRequires:	cimg-devel = %{version}
BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(GraphicsMagick)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	qttools5
%if %{gimpplugin}
BuildRequires:	pkgconfig(gimp-2.0)
%else
Obsoletes:	gimp-plugin-gmic < %{version}-%{release}
%endif

Requires:	%{libname} >= %{version}-%{release}

%description
G'MIC defines a complete image processing framework, and thus
can manage generic image data as other image-related tools.

Anyway, the specific features described below make it a bit particular :

* It internally works with lists of images.
  Image manipulations and interactions can be done
  either grouped or focused on specific items.
* It can process a wide variety of image types,
  including multi-spectral (arbitrary number of channels)
  and 3d volumetric images, as well as image sequences,
  or 3d vector objects.
  Images with different pixel types are supported,
  allowing to process flawlessly images with 8bits or
  16bits integers per channel, as well as float-valued datasets.
* It provides small but efficient visualization modules
  dedicated to the exploration/viewing of 2d/3d multi-spectral images,
  3d vector objects (elevation map, isocurves, isosurfaces,...),
  or 1d graph plots.
* It proposes commands to handle custom interactive windows
  where events can be managed easily by the user.
* It is highly extensible through the importation of custom command
  files which add new commands that become understood by the
  language interpreter.
%if %{gimpplugin}
* Most of the functionalities can be used inside GIMP
  via the provided plug-in, allowing end-users to integrate
  any G'MIC-based pipeline directly in a nice GUI,
  without coding efforts.
%endif
* It is based on the latest development versions of the CImg Library,
  a well established C++ template image processing toolkit,
  developed by the same team of developers.

%files -f %{name}.lang
%doc COPYING README
%{_bindir}/%{name}
%{_bindir}/%{name}_qt
%{_datadir}/bash-completion/completions/%{name}
%{_mandir}/man1/%{name}.1.*
%{_datadir}/applications/gmic_qt.desktop
%{_iconsdir}/hicolor/*/*/gmic_qt.png
%{_iconsdir}/hicolor/*/*/gmic_qt.svg

#------------------------------------------------------

%package -n zart
Summary:        GUI for G'MIC real-time manipulations on the output of a webcam
Group:          Graphics/Utilities
Provides:	%{name}-zart = %{version}-%{release}

%description -n zart
ZArt is a computer program whose purpose is to demonstrate the possibilities of
the G'MIC image processing language by offering the choice of several
manipulations on a video stream acquired from a webcam.

%files -n zart
%{_bindir}/zart
%{_datadir}/applications/zart.desktop
%{_iconsdir}/hicolor/*/*/zart.png
%{_iconsdir}/hicolor/*/*/zart.svg
#%%{_datadir}/zart/haarcascade*.xml

#------------------------------------------------------

%if %{gimpplugin}
%package -n gimp-plugin-%{name}
Summary:	gmic plugin for gimp
Group:		Graphics/Utilities
Requires:	gimp >= 2.6.0
Provides:	%{name}-gimp = %{version}-%{release}

%description -n gimp-plugin-%{name}
G'MIC has been made available as an easy-to-use plug-in for GIMP.
It extends this retouching software capabilities by offering a large number of
pre-defined image filters and effects.
Of course, the plug-in is highly customizable and it is possible to add your
own custom G'MIC-written filters in it.

%files -n gimp-plugin-%{name}
%{_libdir}/gimp/%{abi_version}/plug-ins/%{name}_gimp_qt
%{_libdir}/gimp/%{abi_version}/plug-ins/%{name}_denoise_cnn.gmz
%{_libdir}/gimp/%{abi_version}/plug-ins/%{name}_cluts.gmz
%endif


#------------------------------------------------------

%package -n %{libname}
Summary:	Library for gmic
Group:		System/Libraries

%description -n %{libname}
This package contains the library needed to run programs
dynamically linked with gmic.

%files -n %{libname}
%{_libdir}/lib*%{name}.so.%{major}{,.*}
%{_libdir}/lib*%{name}.so.%{lib_ver}

#------------------------------------------------------

%package -n %{develname}
Summary:	Header file for gmic
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the development file for gmic.

%files -n %{develname}
%{_includedir}/%{name}*.h
%{_libdir}/lib*%{name}.so

#------------------------------------------------------

%prep
%setup -q -a 1 -a 3
#dos2unix src/Makefile
%autopatch -p1

# fix file-not-utf8
iconv -f iso8859-1 -t utf-8 COPYING > COPYING.conv && mv -f COPYING.conv COPYING

# prepare libcgmic from community
mv %{name}-community-gmic-%{version}/libcgmic/* ./src
mv zart-%{zart_version} zart

# We want to build against the system installed CImg package.
# G'MIC provides no way todo this, so we just copy the file over what's there already
pushd src
  mv CImg.h CImg.h.bak
  ln -s /usr/include/CImg.h CImg.h
popd

%build
%set_build_flags

pushd src
%if %{gimpplugin}
	%make_build -j1 all libc NOSTRIP=1 LIB=%{_lib} MAKE="%make_build -j1"
%else
	%make_build -j1 cli lib gmic_qt libc zart libc NOSTRIP=1 LIB=%{_lib} MAKE="%make_build -j1"
%endif
popd

pushd zart
	%qmake_qt5 zart.pro
	%make_build
popd

%install
pushd src
	%make_install LIB=%{_lib}
%if ! %{gimpplugin}
	find %{buildroot} -name '*.gmz' -delete
%endif
popd

pushd zart
	install -m 0755 zart %{buildroot}%{_bindir}/zart
	install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/zart.desktop
	install -Dm 0644 images/gmic_hat.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/zart.png
popd

%find_lang %{name} --with-man


%changelog
* Mon Mar 13 2023 papoteur <papoteur> 3.2.0-1.mga8
+ Revision: 1948784
- new 3.2.0
+ daviddavid <daviddavid>
- re-enable gmic 2 plugin (mga#28515)

* Fri Jan 01 2021 luigiwalser <luigiwalser> 2.9.4-3.mga8
+ Revision: 1667502
- obsolete gimp2.0 plugin
- try rebuilding gimp plugin

* Wed Dec 16 2020 umeabot <umeabot> 2.9.4-2.mga8
+ Revision: 1658495
- Rebuild for new Qt5

* Tue Nov 24 2020 daviddavid <daviddavid> 2.9.4-1.mga8
+ Revision: 1649024
- new version: 2.9.4

* Tue Nov 24 2020 daviddavid <daviddavid> 2.9.3-1.mga8
+ Revision: 1648883
- new version: 2.9.3 (mga#27651)

* Sat Oct 31 2020 joequant <joequant> 2.9.2-1.mga8
+ Revision: 1640802
- add icons
- fix gmic
- use cp and not ln
- update wget
- fix typo
- add CImg.h
- update and rebuild

* Sat Sep 26 2020 tv <tv> 2.9.1-2.mga8
+ Revision: 1630189
- rebuild for new libIlmImf

* Sun Jul 12 2020 daviddavid <daviddavid> 2.9.1-1.mga8
+ Revision: 1605505
- new version: 2.9.1

* Wed Feb 19 2020 umeabot <umeabot> 2.8.3-2.mga8
+ Revision: 1544524
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 daviddavid <daviddavid> 2.8.3-1.mga8
+ Revision: 1483145
- new version: 2.8.3
- rebuild for new opencv 4.2.0
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Wed Oct 30 2019 daviddavid <daviddavid> 2.7.5-1.mga8
+ Revision: 1456797
- new version: 2.7.5

* Tue Sep 03 2019 daviddavid <daviddavid> 2.7.1-1.mga8
+ Revision: 1436545
- new version: 2.7.1

* Tue Aug 20 2019 daviddavid <daviddavid> 2.7.0-1.mga8
+ Revision: 1430430
- new version: 2.7.0

* Tue Jul 02 2019 daviddavid <daviddavid> 2.6.7-1.mga8
+ Revision: 1417557
- new version: 2.6.7

* Wed Apr 17 2019 daviddavid <daviddavid> 2.5.7-1.mga7
+ Revision: 1391860
- new version: 2.5.7

* Wed Apr 10 2019 daviddavid <daviddavid> 2.5.6-1.mga7
+ Revision: 1387857
- new version: 2.5.6

* Tue Apr 02 2019 daviddavid <daviddavid> 2.5.5-1.mga7
+ Revision: 1385355
- new version: 2.5.5

* Sat Mar 30 2019 umeabot <umeabot> 2.5.4-2.mga7
+ Revision: 1381811
- Qt5 Rebuild

* Mon Mar 25 2019 daviddavid <daviddavid> 2.5.4-1.mga7
+ Revision: 1380051
- new version: 2.5.4

* Sun Mar 17 2019 daviddavid <daviddavid> 2.5.3-1.mga7
+ Revision: 1378416
- new version: 2.5.3

* Sun Mar 17 2019 daviddavid <daviddavid> 2.5.2-1.mga7
+ Revision: 1378279
- new version: 2.5.2

* Wed Jan 30 2019 daviddavid <daviddavid> 2.4.5-1.mga7
+ Revision: 1361876
- new version: 2.4.5

* Sat Dec 22 2018 daviddavid <daviddavid> 2.4.3-1.mga7
+ Revision: 1344407
- new version: 2.4.3

* Mon Dec 03 2018 daviddavid <daviddavid> 2.4.2-1.mga7
+ Revision: 1337985
- new version: 2.4.2

* Sat Nov 03 2018 daviddavid <daviddavid> 2.4.1-3.mga7
+ Revision: 1328000
- also add Obsoletes to ease upgrade mga6 -> mga7

* Thu Nov 01 2018 daviddavid <daviddavid> 2.4.1-2.mga7
+ Revision: 1327286
- add Conflicts to ease upgrade mga6 -> mga7

* Wed Oct 31 2018 daviddavid <daviddavid> 2.4.1-1.mga7
+ Revision: 1326819
- new version: 2.4.1

* Tue Oct 16 2018 daviddavid <daviddavid> 2.4.0-2.mga7
+ Revision: 1320944
- rebuild for new ilmbase and openexr 2.3.0

* Fri Oct 05 2018 daviddavid <daviddavid> 2.4.0-1.mga7
+ Revision: 1317897
- new version: 2.4.0

* Wed Sep 05 2018 daviddavid <daviddavid> 2.3.6-1.mga7
+ Revision: 1257227
- new version: 2.3.6

* Sun Jul 22 2018 daviddavid <daviddavid> 2.3.3-1.mga7
+ Revision: 1244770
- new version: 2.3.3
- remove merged upstream patches

* Tue May 29 2018 daviddavid <daviddavid> 2.2.3-1.mga7
+ Revision: 1232898
- new version: 2.2.3
+ wally <wally>
- rebuild for openexr 2.2.1

* Mon May 14 2018 daviddavid <daviddavid> 2.0.0-5.mga7
+ Revision: 1229309
- rebuild for new gegl 0.4.0

* Fri Apr 13 2018 daviddavid <daviddavid> 2.0.0-4.mga7
+ Revision: 1218319
- rebuild for new opencv 3.4.1

* Sat Jan 13 2018 wally <wally> 2.0.0-3.mga7
+ Revision: 1192560
- rebuild for new ilmbase

* Mon Jun 05 2017 akien <akien> 2.0.0-2.mga6
+ Revision: 1106978
- Properly prevent the Makefile from fetching sources
- Remove additional sources already in S0 - only the patch is needed

* Mon Jun 05 2017 akien <akien> 2.0.0-1.mga6
+ Revision: 1106867
- Bundle the headers that would otherwise be downloaded
- Version 2.0.0

* Tue May 02 2017 akien <akien> 1.7.9-2.mga6
+ Revision: 1098288
- Rebuild for ffmpeg 3.3

* Sun Dec 11 2016 daviddavid <daviddavid> 1.7.9-1.mga6
+ Revision: 1074202
- new version: 1.7.9
- now zart and libcgmic are in a separate community tarball

* Mon May 02 2016 daviddavid <daviddavid> 1.7.1-3.mga6
+ Revision: 1008738
- disable also parallel build on other arches
- try to disable parallel build on arm as compilation needs a lot of memory resource

* Sun May 01 2016 daviddavid <daviddavid> 1.7.1-1.mga6
+ Revision: 1008503
- new version: 1.7.1
- rename and rediff nostrip-and-nozart patch

* Mon Feb 08 2016 umeabot <umeabot> 1.6.9-2.mga6
+ Revision: 950773
- Mageia 6 Mass Rebuild

* Mon Feb 08 2016 daviddavid <daviddavid> 1.6.9-1.mga6
+ Revision: 943875
- new version: 1.6.9
- rename and rediff nostrip-and-nozart patch

* Fri Feb 05 2016 daviddavid <daviddavid> 1.6.8-2.mga6
+ Revision: 936947
- disable optimizations flags in upstream makefile

* Thu Feb 04 2016 daviddavid <daviddavid> 1.6.8-1.mga6
+ Revision: 936015
- new version: 1.6.8
- switch zart build to Qt5
- remove no more needed makefile patch
- patch0: fix prevent of stripping binaries and disable zart compilation
  to use our %%qmake_qt5 macro to ensure proper build flags
- add a desktop file and an icon for zart subpackage
- new upstream URL and Source URL
- switch BRs to pkgconfig() and add pkgconfig(libcurl)

* Thu Nov 20 2014 matteo <matteo> 1.6.0.1-1.mga5
+ Revision: 797964
- convert makefile line endings to unix format
- fix zart install
- fix lib installation path
- rediff/redo makefile patch
- new version 1.6.0.1

* Wed Oct 15 2014 umeabot <umeabot> 1.5.7.0-6.mga5
+ Revision: 744551
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.7.0-5.mga5
+ Revision: 679668
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.5.7.0-4.mga5
+ Revision: 666993
- rebuild for ilmbase and OpenEXR

* Thu May 01 2014 luigiwalser <luigiwalser> 1.5.7.0-3.mga5
+ Revision: 619151
- rebuild for ilmbase

* Sat Oct 19 2013 umeabot <umeabot> 1.5.7.0-2.mga4
+ Revision: 534522
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 wally <wally> 1.5.7.0-1.mga4
+ Revision: 478179
- new version 1.5.7.0
- rediff/redo makefile patch

* Thu Sep 12 2013 fwang <fwang> 1.5.5.0-7.mga4
+ Revision: 477935
- use correct ldflags

* Thu Sep 12 2013 fwang <fwang> 1.5.5.0-6.mga4
+ Revision: 477861
- rebuild for new openexr

* Sat Aug 24 2013 wally <wally> 1.5.5.0-5.mga4
+ Revision: 471410
- drop requires added in previous release as seems like libs aren't needed to run gmic/zart

* Sat Aug 24 2013 wally <wally> 1.5.5.0-4.mga4
+ Revision: 471356
- use find_lang macro
- add requires
- add .so file to devel pkg

* Sat Aug 24 2013 wally <wally> 1.5.5.0-3.mga4
+ Revision: 471333
- clean lib pkg requires/obsoletes/provides
- clean unneeded conflicts

* Mon Jun 03 2013 fwang <fwang> 1.5.5.0-2.mga4
+ Revision: 435939
- rebuild for new libpng

* Mon Mar 25 2013 matteo <matteo> 1.5.5.0-1.mga3
+ Revision: 405194
- new version

* Wed Feb 06 2013 matteo <matteo> 1.5.4.0-1.mga3
+ Revision: 394769
- new version

* Sat Jan 12 2013 umeabot <umeabot> 1.5.2.4-2.mga3
+ Revision: 351865
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Mon Dec 10 2012 matteo <matteo> 1.5.2.4-1.mga3
+ Revision: 329360
- new version

* Sun Dec 02 2012 fwang <fwang> 1.5.2.1-2.mga3
+ Revision: 325027
- rebuild for new openexr

* Sat Nov 03 2012 matteo <matteo> 1.5.2.1-1.mga3
+ Revision: 313458
- fixed subpackages group
- fixed group
- new version

* Tue Sep 04 2012 fwang <fwang> 1.5.1.9-2.mga3
+ Revision: 287848
- update ldflags

* Tue Sep 04 2012 matteo <matteo> 1.5.1.9-1.mga3
+ Revision: 287809
- new version

* Sat Aug 18 2012 matteo <matteo> 1.5.1.8-1.mga3
+ Revision: 281962
- new version

* Sat Jul 28 2012 matteo <matteo> 1.5.1.7-1.mga3
+ Revision: 275079
- new version

* Sat Jun 23 2012 matteo <matteo> 1.5.1.6-2.mga3
+ Revision: 262775
- added missing br graphicsmagick-devel
- removed gimp-plugin unnecessary requirement

* Fri Jun 22 2012 matteo <matteo> 1.5.1.6-1.mga3
+ Revision: 262700
- new upstream version 1.5.1.6

* Wed Jun 20 2012 matteo <matteo> 1.5.1.5-3.mga3
+ Revision: 262241
- fix obsoletes to solve dependencies error

* Tue Jun 19 2012 matteo <matteo> 1.5.1.5-2.mga3
+ Revision: 261831
- fix gmic and gimp-plugin-gmic descriptions
- fix unversioned provide (zart)
- remove old and unnecessary patches

* Mon Jun 18 2012 matteo <matteo> 1.5.1.5-1.mga3
+ Revision: 261822
- moved gimp requirement from gmic to gimp-plugin-gmic
- libname description improved
- imported package gmic

